@@ -51,6 +51,8 @@
 #define NOSYNC "/etc/runit/nosync"
 #define DOFSCK "/forcefsck"
 #define NOFSCK "/fastboot"
+#define SUSAGE "Usage: shutdown [-F] [-f] [-r] [-h] [now] \n"
+#define HUSAGE "Usage: halt  [-n] [-f] [-w] \n"
 
 #define write2(msg) write(2, msg, sizeof(msg))
 typedef enum shutdown_action { ACTION_REBOOT, ACTION_HALT } shutdown_action;
@@ -77,6 +79,7 @@ struct config {
 	bool nofsck;
 	bool dofsck;
 	bool noop;		/*stop and exit 0 without actually reboot or poweroff  */
+	bool error;
 };
 
 struct stat s;
@@ -158,6 +161,7 @@ parse_command_line(struct config *cfg, int argc, char **argv)
 	cfg->dofsck = false;
 	cfg->nofsck = false;
 	cfg->noop = false;
+	cfg->error = false;
 
 	if (strstr(argv[0], "reboot")) {
 		cfg->action = ACTION_REBOOT;
@@ -165,6 +169,10 @@ parse_command_line(struct config *cfg, int argc, char **argv)
 
 	for (i = 1; i != argc; ++i) {
 		if (strstr(argv[0], "shutdown")) {
+			if (strcmp(argv[i], "-h") == 0) {
+				/* the default */
+				continue;
+			}
 			if (strcmp(argv[i], "-r") == 0) {
 				cfg->action = ACTION_REBOOT;
 				continue;
@@ -177,6 +185,21 @@ parse_command_line(struct config *cfg, int argc, char **argv)
 				cfg->dofsck = true;
 				continue;
 			}
+			if (argv[i][0]  == '-') {
+				write2(SUSAGE);
+				cfg->error = true;
+				break;
+			}
+			if (strcmp(argv[i], "now") == 0) {
+				/*write2("time argument ignored\n"); */
+				continue;
+			}
+			else {
+				/* time spec and shutdown message not supported */
+				write2(SUSAGE);
+				cfg->error = true;
+				break;
+			}
 		}
 		else {
 			if (strcmp(argv[i], "-f") == 0) {
@@ -206,6 +229,13 @@ parse_command_line(struct config *cfg, int argc, char **argv)
 				cfg->nosync = true;
 				continue;
 			}
+			else {
+				write2("WARNING: -d -h -p -i : ignored options\n");
+				write2(HUSAGE);
+				/*cfg->error = true; breaks sysv--> runit-init switch*/
+				/*break;*/
+				continue;
+			}
 		}
 	}
 }
@@ -222,6 +252,9 @@ main(int argc, char **argv)
 		write2("shutdown: must be superuser.\n");
 		return 2;
 	}
+	if (cfg.error) {
+		return 1;
+	}
 	if (cfg.noop) {
 		// No-Op: see #919699 and #899246
 		return 0;
